@@ -18,4 +18,7 @@ public class GCubePortalConstants {
 	public static final String SENDER_EMAIL = "notificationSenderEmail";
 	public static final String GATEWAY_NAME = "portalinstancename";
 	public static final String ADMIN_USERNAME = "administratorUsername";
+	
+	public static final String VRE_ID_ATTR_NAME = "gcube-vreid";
+	public static final String USER_ID_ATTR_NAME = "gcube-userId";
 }
