@@ -11,9 +11,10 @@ import java.util.Properties;
 
 import javax.servlet.http.HttpServletRequest;
 
+import org.gcube.common.authorization.client.exceptions.ObjectNotFound;
+import org.gcube.common.authorization.library.provider.SecurityTokenProvider;
 import org.gcube.common.authorization.library.provider.UserInfo;
 import org.gcube.common.scope.api.ScopeProvider;
-import org.gcube.portal.clientcontext.client.GCubeClientContext;
 import org.gcube.vomanagement.usermanagement.impl.LiferayGroupManager;
 import org.gcube.vomanagement.usermanagement.impl.LiferayUserManager;
 import org.gcube.vomanagement.usermanagement.model.CustomAttributeKeys;
@@ -42,7 +43,8 @@ import com.liferay.portal.util.PortalUtil;
  */
 public class PortalContext {
 	private static final Logger _log = LoggerFactory.getLogger(PortalContext.class);
-
+	public static final String VRE_ID_ATTR_NAME = "gcube-vreid";
+	public static final String USER_ID_ATTR_NAME = "gcube-userId";
 	/**
 	 * Scope separators used in linear syntax.
 	 */
@@ -59,7 +61,9 @@ public class PortalContext {
 	private static final String DEV_USER_LASTNAME_ATTR = "user.lastname";
 	private static final String DEV_USER_EMAIL_ATTR = "user.email";
 
-	private static final String DEV_SCOPE_ATTR = "development.scope";
+	private static final String DEV_SCOPE_ATTR = "development.context";
+	private static final String DEV_GROUP_NAME_ATTR = "development.groupname";
+	private static final String DEV_GROUP_ID_ATTR = "development.groupid";
 	private static final String DEV_TOKEN_ATTR = "user.token";
 
 
@@ -126,25 +130,20 @@ public class PortalContext {
 	/**
 	 * 
 	 * @param httpServletRequest the httpServletRequest object
-	 * @return the instance of the user 
+	 * @return the instance of the current user 
 	 * @see GCubeUser
 	 */
 	public GCubeUser getCurrentUser(HttpServletRequest httpServletRequest) {
-		String userIdNo = httpServletRequest.getHeader(GCubeClientContext.USER_ID_ATTR_NAME);
+		Long userIdNo = ContextUserUtil.getCurrentUserId(httpServletRequest);
 		if (userIdNo != null) {
-			long userId = -1;
 			try {
-				userId = Long.parseLong(userIdNo);
-				return new LiferayUserManager().getUserById(userId);
-			} catch (NumberFormatException e) {
-				_log.error("The userId is not a number -> " + userId);
-			} catch (Exception e) {
-				_log.error("The userId does not belong to any user -> " + userId);
+				return new LiferayUserManager().getUserById(userIdNo);
+			}  catch (Exception e) {
+				_log.error("The userId does not belong to any user -> " + userIdNo);
 			}
 		} else {
 			if (isWithinPortal()) {
-				_log.error("It seems your app is running in Liferay but not context was set on this (HttpServletRequest) request, "
-						+ "make sure you have set the gCube ClientContext correctly in your code.");
+				_log.warn("Could not read the current userid, either session expired or user not logged in");
 			} else {
 				GCubeUser toReturn = readUserFromPropertyFile();
 				_log.debug("getCurrentUser devMode into IDE detected, returning testing user: " + toReturn.toString());
@@ -153,19 +152,16 @@ public class PortalContext {
 		}
 		return null;
 	}
-
 	/**
 	 * 
-	 * @param httpServletRequest the httpServletRequest object
-	 * @return the instance of the user 
-	 * @see GCubeUser
+	 * @param scopeGroupId the liferay groupid number (as String) of the VRE/VO
+	 * @return the scope (context)
 	 */
-	public String getCurrentScope(HttpServletRequest httpServletRequest) {
-		String groupIdNo = httpServletRequest.getHeader(GCubeClientContext.VRE_ID_ATTR_NAME);
-		if (groupIdNo != null) {
+	public String getCurrentScope(String scopeGroupId) {
+		if (scopeGroupId != null) {
 			long groupId = -1;
 			try {
-				groupId = Long.parseLong(groupIdNo);
+				groupId = Long.parseLong(scopeGroupId);
 				LiferayGroupManager gm = new LiferayGroupManager();
 				if (gm.isRootVO(groupId)) {
 					return SCOPE_SEPARATOR + getInfrastructureName();
@@ -177,11 +173,8 @@ public class PortalContext {
 				_log.error("This groupId does not belong to any group in this portal -> " + groupId);
 			}
 		} else {
-			if (isWithinPortal()) {
-				_log.error("It seems your app is running in Liferay but not context was set on this (HttpServletRequest) request, "
-						+ "make sure you have set the gCube ClientContext correctly in your code.");
-			} else {
-				String toReturn = readScopePropertyFile();
+			if (!isWithinPortal()) {
+				String toReturn = readContextPropertyFile();
 				_log.debug("getCurrentScope devMode into IDE detected, returning scope: " + toReturn.toString());
 				_log.debug("The PortalBeanLocatorUtil stacktrace (java.lang.Exception) is acceptable in dev");
 				return toReturn;
@@ -189,51 +182,163 @@ public class PortalContext {
 		}
 		return null;
 	}
-
+	/**
+	 * 
+	 * @param httpServletRequest the httpServletRequest object
+	 * @return the scope (context)
+	 */
+	public String getCurrentScope(HttpServletRequest httpServletRequest) {
+		String scopeGroupId = httpServletRequest.getHeader(VRE_ID_ATTR_NAME);
+		return getCurrentScope(scopeGroupId);
+	} 
 	/**
 	 * 
 	 * @param httpServletRequest the httpServletRequest object
 	 * @return the instance of the user 
 	 * @see GCubeUser
 	 */
-	public String getCurrentUserToken(HttpServletRequest httpServletRequest) {
-		String groupIdNo = httpServletRequest.getHeader(GCubeClientContext.VRE_ID_ATTR_NAME);
+	public String getCurrentGroupName(HttpServletRequest httpServletRequest) {
+		String groupIdNo = httpServletRequest.getHeader(VRE_ID_ATTR_NAME);
 		if (groupIdNo != null) {
-			String scope = getCurrentScope(httpServletRequest);
-			String username = getCurrentUser(httpServletRequest).getUsername();
+			long groupId = -1;
 			try {
-				return getAuthorizationToken(username, scope);
+				groupId = Long.parseLong(groupIdNo);
+				LiferayGroupManager gm = new LiferayGroupManager();
+				return gm.getGroup(groupId).getGroupName();
+			} catch (NumberFormatException e) {
+				_log.error("The groupId is not a number -> " + groupId);
 			} catch (Exception e) {
-				_log.error("Error while trying to generate token for user " + username + "in scope " + scope);
-				e.printStackTrace();
-				return null;
+				_log.error("This groupId does not belong to any group in this portal -> " + groupId);
 			}
 		} else {
-			if (isWithinPortal()) {
-				_log.error("It seems your app is running in Liferay but not context was set on this (HttpServletRequest) request, "
-						+ "make sure you have set the gCube ClientContext correctly in your code.");
-			} else {
-				String toReturn = readTokenPropertyFile();
-				_log.debug("getCurrentToken devMode into IDE detected, returning scope: " + toReturn.toString());
+			if (!isWithinPortal()) {
+				String toReturn = readGroupNamePropertyFile();
+				_log.debug("getCurrentGroupName devMode into IDE detected, returning group name: " + toReturn.toString());
 				_log.debug("The PortalBeanLocatorUtil stacktrace (java.lang.Exception) is acceptable in dev");
 				return toReturn;
 			}
 		}
 		return null;
 	}
+	/**
+	 * 
+	 * @param httpServletRequest the httpServletRequest object
+	 * @return the instance of the user 
+	 * @see GCubeUser
+	 */
+	public long getCurrentGroupId(HttpServletRequest httpServletRequest) {
+		String groupIdNo = httpServletRequest.getHeader(VRE_ID_ATTR_NAME);
+		if (groupIdNo != null) {
+			long groupId = -1;
+			try {
+				groupId = Long.parseLong(groupIdNo);
+				return groupId;
+			} catch (NumberFormatException e) {
+				_log.error("The groupId is not a number -> " + groupId);
+			} catch (Exception e) {
+				_log.error("This groupId does not belong to any group in this portal -> " + groupId);
+			}
+		} else {
+			if (!isWithinPortal()) {
+				long toReturn = readGroupIdPropertyFile();
+				_log.debug("getCurrentGroup devMode into IDE detected, returning groupid = " + toReturn);
+				_log.debug("The PortalBeanLocatorUtil stacktrace (java.lang.Exception) is acceptable in dev");
+				return toReturn;
+			}
+		}
+		return -1;
+	}
+
+
+	/**
+	 * @deprecated use only with AJAX Calls
+	 * @param httpServletRequest the httpServletRequest object
+	 * @return the instance of the user 
+	 * @see GCubeUser
+	 */
+	public String getCurrentUserToken(HttpServletRequest httpServletRequest) {
+		String groupIdNo = httpServletRequest.getHeader(VRE_ID_ATTR_NAME);
+		String userToken = null;
+		if (groupIdNo != null) {
+			String scope = getCurrentScope(httpServletRequest);
+			String username = getCurrentUser(httpServletRequest).getUsername();
+			try {
+				ScopeProvider.instance.set(scope);
+				userToken = authorizationService().resolveTokenByUserAndContext(username, scope);
+				SecurityTokenProvider.instance.set(userToken);
+			} 
+			catch (ObjectNotFound ex) {
+				userToken = generateAuthorizationToken(username, scope);
+				SecurityTokenProvider.instance.set(userToken);
+				_log.debug("generateAuthorizationToken OK for " + username + " in scope " + scope);
+			}			 
+			catch (Exception e) {
+				_log.error("Error while trying to generate token for user " + username + "in scope " + scope);
+				e.printStackTrace();
+				return null;
+			}
+		} else {
+			if (isWithinPortal()) {
+				_log.warn("It seems your app is running in Liferay but not context was set on this (HttpServletRequest) request");
+			} else {
+				String toReturn = readTokenPropertyFile();
+				_log.debug("getCurrentToken devMode into IDE detected, returning scope: " + toReturn.toString());
+				_log.debug("The PortalBeanLocatorUtil stacktrace (java.lang.Exception) is acceptable in dev");
+				return toReturn;
+			}
+		}
+		return userToken;
+	}
+	/**
+	 * @param httpServletRequest the httpServletRequest object
+	 * @param scope the infrastructure scope
+	 * @return the instance of the user 
+	 * @see GCubeUser
+	 */
+	public String getCurrentUserToken(String scope, HttpServletRequest httpServletRequest) {
+		String userToken = null;
+		if (isWithinPortal()) {
+			String username = getCurrentUser(httpServletRequest).getUsername();
+			try {
+				ScopeProvider.instance.set(scope);
+				userToken = authorizationService().resolveTokenByUserAndContext(username, scope);
+				SecurityTokenProvider.instance.set(userToken);
+			} 
+			catch (ObjectNotFound ex) {
+				userToken = generateAuthorizationToken(username, scope);
+				SecurityTokenProvider.instance.set(userToken);
+				_log.debug("generateAuthorizationToken OK for " + username + " in scope " + scope);
+			}			 
+			catch (Exception e) {
+				_log.error("Error while trying to generate token for user " + username + "in scope " + scope);
+				e.printStackTrace();
+				return null;
+			}
+		} else {
+			String toReturn = readTokenPropertyFile();
+			_log.debug("getCurrentToken devMode into IDE detected, returning scope: " + toReturn.toString());
+			_log.debug("The PortalBeanLocatorUtil stacktrace (java.lang.Exception) is acceptable in dev");
+			return toReturn;
+		}
+		return userToken;
+	}
+
 	/**
 	 * 
 	 * @param username
 	 * @param scope
 	 * @throws Exception
 	 */
-	private static String getAuthorizationToken(String username, String scope) throws Exception {
-		ScopeProvider.instance.set(scope);
-		_log.debug("calling service token on scope " + scope);
+	private static String generateAuthorizationToken(String username, String scope) {
 		List<String> userRoles = new ArrayList<>();
 		userRoles.add(DEFAULT_ROLE);
-		String token = authorizationService().generateUserToken(new UserInfo(username, userRoles), scope);
-		_log.debug("received token: "+token);
+		String token;
+		try {
+			token = authorizationService().generateUserToken(new UserInfo(username, userRoles), scope);
+		} catch (Exception e) {
+			e.printStackTrace();
+			return null;
+		}
 		return token;
 	}
 	/**
@@ -363,7 +468,7 @@ public class PortalContext {
 	 * @param request
 	 * @return the current Group instance based on the request
 	 */
-	public Group getSiteFromServletRequest(final HttpServletRequest request) throws Exception {
+	private Group getSiteFromServletRequest(final HttpServletRequest request) throws Exception {
 		String serverName = request.getServerName();
 		Group site = null;
 		List<VirtualHost> vHosts = VirtualHostLocalServiceUtil.getVirtualHosts(0, VirtualHostLocalServiceUtil.getVirtualHostsCount());
@@ -384,7 +489,7 @@ public class PortalContext {
 	 * @param serverName e.g. myportal.mydomain.org
 	 * @return the Liferay Group instance responding to the servename passed as parameter
 	 */
-	public Group getSiteFromServerName(final String serverName) throws Exception {
+	private Group getSiteFromServerName(final String serverName) throws Exception {
 		_log.debug("serverName passed is " +  serverName);
 		Group site = null;
 		List<VirtualHost> vHosts = VirtualHostLocalServiceUtil.getVirtualHosts(0, VirtualHostLocalServiceUtil.getVirtualHostsCount());
@@ -536,10 +641,10 @@ public class PortalContext {
 	/**
 	 * for development purposes only
 	 */
-	private static GCubeUser readUserFromPropertyFile() {
+	protected static GCubeUser readUserFromPropertyFile() {
 		Properties props = new Properties();
 		try {
-			StringBuilder sb = new StringBuilder(getCatalinaHome());
+			StringBuilder sb = new StringBuilder(getGCubeDevHome());
 			sb.append(File.separator)
 			.append(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME);
 			String propertyfile = sb.toString();
@@ -562,7 +667,7 @@ public class PortalContext {
 			return new GCubeUser(userId, username, email, firstName, middleName, lastName, fullname, registrationDate, userAvatarId, male, jobTitle, emailAddresses);
 		}
 		catch(IOException e) {
-			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $CATALINA_HOME dir");
+			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $GCUBE_DEV_HOME dir");
 			return null;
 		}		
 	}
@@ -572,7 +677,7 @@ public class PortalContext {
 	private static String readTokenPropertyFile() {
 		Properties props = new Properties();
 		try {
-			StringBuilder sb = new StringBuilder(getCatalinaHome());
+			StringBuilder sb = new StringBuilder(getGCubeDevHome());
 			sb.append(File.separator)
 			.append(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME);
 			String propertyfile = sb.toString();
@@ -588,16 +693,18 @@ public class PortalContext {
 			}			
 		}
 		catch(IOException e) {
-			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $CATALINA_HOME dir");
+			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $GCUBE_DEV_HOME dir");
 			return null;
 		}		
-	}/**
+	}
+
+	/**
 	 * for development purposes only
 	 */
-	private static String readScopePropertyFile() {
+	private static String readContextPropertyFile() {
 		Properties props = new Properties();
 		try {
-			StringBuilder sb = new StringBuilder(getCatalinaHome());
+			StringBuilder sb = new StringBuilder(getGCubeDevHome());
 			sb.append(File.separator)
 			.append(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME);
 			String propertyfile = sb.toString();
@@ -613,10 +720,73 @@ public class PortalContext {
 			}			
 		}
 		catch(IOException e) {
-			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $CATALINA_HOME dir");
+			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $GCUBE_DEV_HOME dir");
 			return null;
 		}		
 	}
+	/**
+	 * for development purposes only
+	 */
+	private static String readGroupNamePropertyFile() {
+		Properties props = new Properties();
+		try {
+			StringBuilder sb = new StringBuilder(getGCubeDevHome());
+			sb.append(File.separator)
+			.append(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME);
+			String propertyfile = sb.toString();
+			File propsFile = new File(propertyfile);
+			FileInputStream fis = new FileInputStream(propsFile);
+			props.load( fis);
+			String groupName  = props.getProperty(DEV_GROUP_NAME_ATTR);
+			if (groupName != null && !groupName.isEmpty())
+				return groupName;
+			else {
+				_log.error("groupName is not valid, check property " + DEV_GROUP_NAME_ATTR);
+				return null;
+			}			
+		}
+		catch(IOException e) {
+			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $GCUBE_DEV_HOME dir");
+			return null;
+		}		
+	}
+
+	/**
+	 * for development purposes only
+	 */
+	private static long readGroupIdPropertyFile() {
+		Properties props = new Properties();
+		try {
+			StringBuilder sb = new StringBuilder(getGCubeDevHome());
+			sb.append(File.separator)
+			.append(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME);
+			String propertyfile = sb.toString();
+			File propsFile = new File(propertyfile);
+			FileInputStream fis = new FileInputStream(propsFile);
+			props.load( fis);
+			String groupIdNo  = props.getProperty(DEV_GROUP_ID_ATTR);
+			long groupId = -1;
+			if (groupIdNo != null) {
+				try {
+					groupId = Long.parseLong(groupIdNo);
+					return groupId;
+				} catch (NumberFormatException e) {
+					_log.error("The groupId is not a number -> " + groupIdNo);
+				}
+			}
+			else {
+				_log.error("groupId is not valid, check property " + DEV_GROUP_ID_ATTR);
+				return -1L;
+			}			
+		}
+		catch(IOException e) {
+			_log.error(GCUBE_DEV__CONTEXT_PROPERTY_FILENAME + " file not found under $GCUBE_DEV_HOME dir");
+			return -1L;
+		}		
+		return -1L;
+	}
+
+
 	/**
 	 * 
 	 * @return $CATALINA_HOME
@@ -625,4 +795,15 @@ public class PortalContext {
 		return (System.getenv("CATALINA_HOME").endsWith("/") ? System.getenv("CATALINA_HOME") : System.getenv("CATALINA_HOME")+"/");
 	}
 
+	/**
+	 * 
+	 * @return $GCUBE-DEV-HOME
+	 */
+	private static String getGCubeDevHome() {
+		return (System.getenv("GCUBE_DEV_HOME").endsWith("/") ? System.getenv("GCUBE_DEV_HOME") : System.getenv("GCUBE_DEV_HOME")+"/");
+	}
+
+
+
+
 }
