@@ -3,6 +3,7 @@ package org.gcube.vomanagement.usermanagement.impl;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -23,12 +24,15 @@ import org.gcube.vomanagement.usermanagement.model.GCubeUser;
 import org.gcube.vomanagement.usermanagement.model.MembershipRequestStatus;
 import org.gcube.vomanagement.usermanagement.util.ManagementUtils;
 
+import com.liferay.portal.kernel.dao.orm.QueryUtil;
 import com.liferay.portal.kernel.exception.PortalException;
 import com.liferay.portal.kernel.exception.SystemException;
 import com.liferay.portal.kernel.log.Log;
 import com.liferay.portal.kernel.log.LogFactoryUtil;
 import com.liferay.portal.kernel.util.DigesterUtil;
 import com.liferay.portal.kernel.util.HttpUtil;
+import com.liferay.portal.kernel.util.OrderByComparator;
+import com.liferay.portal.kernel.util.OrderByComparatorFactoryUtil;
 import com.liferay.portal.model.Contact;
 import com.liferay.portal.model.EmailAddress;
 import com.liferay.portal.model.Group;
@@ -499,7 +503,7 @@ public class LiferayUserManager implements UserManager {
 	 * {@inheritDoc}
 	 */
 	@Override
-	public GCubeUser getUserByEmail(String emailAddress)	throws UserManagementSystemException, UserRetrievalFault {
+	public GCubeUser getUserByEmail(String emailAddress) throws UserManagementSystemException, UserRetrievalFault {
 		User toGet = null;
 		GCubeUser toReturn = null;
 		try {
@@ -531,7 +535,8 @@ public class LiferayUserManager implements UserManager {
 	public List<GCubeUser> listUsers() throws UserManagementSystemException {
 		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
 		try {
-			List<User> lrUsers = UserLocalServiceUtil.getUsers(0, UserLocalServiceUtil.getUsersCount());
+			OrderByComparator comparator = OrderByComparatorFactoryUtil.create("User_", "screenname", true);
+			List<User> lrUsers = UserLocalServiceUtil.search(ManagementUtils.getCompany().getCompanyId(), "", 0, null, QueryUtil.ALL_POS, QueryUtil.ALL_POS, comparator);
 			for (User user : lrUsers) {
 				if (user.isActive())
 					toReturn.add(mapLRUser(user));
@@ -550,7 +555,11 @@ public class LiferayUserManager implements UserManager {
 	public List<GCubeUser> listUsersByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault {
 		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
 		try {
-			for (User user : UserLocalServiceUtil.getGroupUsers(groupId)) {
+			OrderByComparator comparator = OrderByComparatorFactoryUtil.create("User_", "screenname", true);
+			LinkedHashMap<String, Object> params = new LinkedHashMap<String, Object>();
+			params.put("usersGroups", groupId);			
+			List<User> usersByGroup = UserLocalServiceUtil.search(ManagementUtils.getCompany().getCompanyId(), "", 0, params, QueryUtil.ALL_POS, QueryUtil.ALL_POS, comparator);
+			for (User user : usersByGroup) {
 				if (user.isActive())
 					toReturn.add(mapLRUser(user));
 			}
@@ -569,10 +578,7 @@ public class LiferayUserManager implements UserManager {
 		List<GCubeUser> toReturn = new ArrayList<GCubeUser>();
 		try {
 			Group g = (GroupLocalServiceUtil.getGroup(ManagementUtils.getCompany().getCompanyId(), name));
-			for (User user : UserLocalServiceUtil.getGroupUsers(g.getGroupId())) {
-				if (user.isActive())
-					toReturn.add(mapLRUser(user));
-			}
+			return listUsersByGroup(g.getGroupId());
 		} catch (PortalException e) {
 			e.printStackTrace();
 		} catch (SystemException e) {
@@ -590,7 +596,12 @@ public class LiferayUserManager implements UserManager {
 			Group g = GroupLocalServiceUtil.getGroup(groupId);
 			_log.debug("Asked for users and roles of group: "+g.getName());			
 
-			for (User user : UserLocalServiceUtil.getGroupUsers(groupId)) {
+			OrderByComparator comparator = OrderByComparatorFactoryUtil.create("User_", "screenname", true);
+			LinkedHashMap<String, Object> params = new LinkedHashMap<String, Object>();
+			params.put("usersGroups", groupId);			
+			List<User> usersByGroup = UserLocalServiceUtil.search(ManagementUtils.getCompany().getCompanyId(), "", 0, params, QueryUtil.ALL_POS, QueryUtil.ALL_POS, comparator);
+			
+			for (User user : usersByGroup) {
 				if (user.isActive()) {
 					long userId = user.getUserId();
 					doAsAdmin();					
